@@ -1,15 +1,16 @@
 `plot.paleoTS` <-
-function (x, nse=1, yl=NULL, pch=19, true.means=FALSE, start.time=NULL, add=FALSE, ...)
+function (x, nse=1, yl=NULL, pch=NULL, pool=TRUE, true.means=FALSE, add=FALSE, ...)
 # plots paleoTS object, with nse*se error bars
 {
+  if (pool)	x<- pool.var(x, ret.paleoTS=TRUE)
   se<- sqrt(x$vv/x$nn)
   lci<- x$mm-(nse*se)
   uci<- x$mm+(nse*se)
   if (is.null(yl))
      yl<-range(c(lci, uci))
 
-  if (!is.null(start.time))
-     x$tt<- x$tt-start.time
+  if (!is.null(x$start.age))
+     x$tt<- x$tt-x$start.age
      
   if (is.null(pch))
   	pch=19
@@ -22,7 +23,6 @@ function (x, nse=1, yl=NULL, pch=19, true.means=FALSE, start.time=NULL, add=FALS
   else
    {
     plot (x$tt, x$mm, type="o", pch=pch, xlab="Time", ylab="Trait Mean", ylim=yl, ...)
-    #mtext(x$label, side=3, col="grey", font=3, cex=0.6)
    }
   segments (x$tt, lci, x$tt, uci, lty=1, ...)
   
